@@ -1,8 +1,9 @@
 use combine::parser::EasyParser;
 use tui::style::{Color, Modifier, Style};
+use config_macros::ConfParsable;
 
 // Config definition
-#[derive(Default)]
+#[derive(Default, ConfParsable)]
 pub struct Config {
   pub show_hidden: bool,
   pub open_cmd: String,
@@ -12,35 +13,7 @@ pub struct Config {
   pub dir_name_style: Style,
   pub file_name_style: Style,
   pub highlight_style: Style,
-}
-
-impl ConfTree for Config {
-  fn get_child(&self, name: &str) -> Result<&dyn ConfOpt, String> {
-    match name {
-      "open_cmd" => Ok(&self.open_cmd),
-      "show_hidden" => Ok(&self.show_hidden),
-      "quit_on_open" => Ok(&self.quit_on_open),
-      "file_icons" => Ok(&self.file_icons),
-      "icon_style" => Ok(&self.icon_style),
-      "dir_name_style" => Ok(&self.dir_name_style),
-      "file_name_style" => Ok(&self.file_name_style),
-      "highlight_style" => Ok(&self.highlight_style),
-      _ => Err(format!("unknown option {}", name)),
-    }
-  }
-  fn get_child_mut(&mut self, name: &str) -> Result<&mut dyn ConfOpt, String> {
-    match name {
-      "open_cmd" => Ok(&mut self.open_cmd),
-      "show_hidden" => Ok(&mut self.show_hidden),
-      "quit_on_open" => Ok(&mut self.quit_on_open),
-      "file_icons" => Ok(&mut self.file_icons),
-      "icon_style" => Ok(&mut self.icon_style),
-      "dir_name_style" => Ok(&mut self.dir_name_style),
-      "file_name_style" => Ok(&mut self.file_name_style),
-      "highlight_style" => Ok(&mut self.highlight_style),
-      _ => Err(format!("unknown option {}", name)),
-    }
-  }
+  pub link_style: Style,
 }
 
 impl Config {
@@ -55,6 +28,16 @@ impl Config {
 
 // Lib functions
 
+trait ConfOpt {
+  fn set_opt(&mut self, val: &str) -> Result<(), String>;
+  fn get_opt(&self) -> String;
+}
+
+trait ConfTree {
+  fn get_child(&self, name: &str) -> Result<&dyn ConfOpt, String>;
+  fn get_child_mut(&mut self, name: &str) -> Result<&mut dyn ConfOpt, String>;
+}
+
 fn parse_opt<T: std::str::FromStr>(val: &str) -> Result<T, String> {
   match val.parse::<T>() {
     Ok(res) => Ok(res),
@@ -62,11 +45,6 @@ fn parse_opt<T: std::str::FromStr>(val: &str) -> Result<T, String> {
   }
 }
 
-trait ConfOpt {
-  fn set_opt(&mut self, val: &str) -> Result<(), String>;
-  fn get_opt(&self) -> String;
-}
-
 impl ConfOpt for bool {
   fn set_opt(&mut self, val: &str) -> Result<(), String> {
     *self = parse_opt(val)?;
@@ -172,11 +150,6 @@ impl ConfOpt for Style {
   }
 }
 
-trait ConfTree {
-  fn get_child(&self, name: &str) -> Result<&dyn ConfOpt, String>;
-  fn get_child_mut(&mut self, name: &str) -> Result<&mut dyn ConfOpt, String>;
-}
-
 mod style_parser {
   use combine::parser::char::*;
   use combine::parser::EasyParser;
@@ -333,14 +306,14 @@ mod tests {
     );
     assert_eq!(
       Style::default()
-        .fg(Yellow)
+        .fg(Indexed(1))
         .bg(Rgb(0x00, 0x11, 0xFF))
         .add_modifier(Modifier::BOLD)
         .remove_modifier(Modifier::UNDERLINED)
         .remove_modifier(Modifier::ITALIC)
         .get_opt()
         .as_str(),
-      "yellow,rgb:0011FF+b-iu"
+      "color1,rgb:0011FF+b-iu"
     );
   }
 }
