@@ -168,6 +168,15 @@ impl FileTreeState {
   fn rebuild_list(&mut self, cfg: &Config) {
     self.lines.items = self.root_entry.build_lines_rec(cfg, 0).collect();
   }
+
+  pub fn current_dir(&self) -> PathBuf {
+    let sel = self.entry();
+    if sel.is_dir {
+      sel.path.clone()
+    } else {
+      sel.path.parent().map(PathBuf::from).unwrap_or(PathBuf::from("/"))
+    }
+  }
 }
 
 pub struct FileTree<'a> {
@@ -282,15 +291,19 @@ impl TreeEntry {
     self.children.sort_by(|a, b| b.is_dir.cmp(&a.is_dir));
   }
 
-  fn should_show_item(&self, conf: &Config, _level: usize) -> bool {
-    if !conf.show_hidden
+  fn should_show_item(&self, conf: &Config, level: usize) -> bool {
+    // Always show root dir
+    if level == 0 {
+      return true;
+    }
+    let hidden = !conf.show_hidden
       && self
         .path
         .file_name()
         .and_then(|s| s.to_str())
         .map(|x| x.starts_with("."))
-        .unwrap_or(false)
-    {
+        .unwrap_or(false);
+    if hidden {
       return false;
     }
     return true;
@@ -344,6 +357,11 @@ impl TreeEntry {
       } else {
         conf.file_name_style
       };
+      let mainstyle = if self.is_link {
+        mainstyle.patch(conf.link_style)
+      } else {
+        mainstyle
+      };
       TreeEntryLine {
         path: self.path.clone(),
         line: vec![
